@@ -1,14 +1,5 @@
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# Copyright 2018-2022 contributors to the OpenLineage project
+# SPDX-License-Identifier: Apache-2.0
 
 from typing import Dict, List, Optional
 from enum import Enum
@@ -74,5 +65,5 @@ class RunEvent:
     run: Run = attr.ib()
     job: Job = attr.ib()
     producer: str = attr.ib()
-    inputs: Optional[List[Dataset]] = attr.ib(factory=list)
-    outputs: Optional[List[Dataset]] = attr.ib(factory=list)
+    inputs: Optional[List[Dataset]] = attr.ib(factory=list)     # type: ignore
+    outputs: Optional[List[Dataset]] = attr.ib(factory=list)    # type: ignore
